DeviceCalendar class

Constructors

DeviceCalendar({required String id, required String display_name, required String account_name, required String calendar_color})
DeviceCalendar.fromMap(Map<String, dynamic> map)
factory

Properties

account_name String
final
calendar_color String
final
display_name String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited