Event class

Constructors

Event({required String title, required String startTime, required String endTime, required String eventTimeZone, String? description, String? location, String? eventId, String? color})
Event.fromMap(Map<String, dynamic> map)
factory

Properties

color String?
final
description String?
final
endTime String
final
eventId String?
final
eventTimeZone String
final
hashCode int
The hash code for this object.
no setterinherited
location String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTime String
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited