MethodChannelFlAddToCalenderPlus class
An implementation of FlAddToCalenderPlusPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- FlAddToCalenderPlusPlatform
- MethodChannelFlAddToCalenderPlus
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addEventToCalendar(
{required Event event, Function? onPermissionDenied, required String calendarId}) → Future< String?> -
override
-
getAvailableCalendarApps(
) → Future< List< DeviceCalendar> > -
override
-
getPlatformVersion(
) → Future< String?> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited