FlAddToCalenderPlusPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- FlAddToCalenderPlusPlatform
- Implementers
Constructors
- FlAddToCalenderPlusPlatform()
- Constructs a FlAddToCalenderPlusPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addEventToCalendar(
{required Event event, Function? onPermissionDenied, required String calendarId}) → Future< String?> -
getAvailableCalendarApps(
) → Future< List< DeviceCalendar> > -
getPlatformVersion(
) → Future< String?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ FlAddToCalenderPlusPlatform
-
The default instance of FlAddToCalenderPlusPlatform to use.
getter/setter pair