FlAddToCalenderPlus class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
addEvent(BuildContext context, {required Event event, Function? onPermissionDenied, Function? onError, Function? onSubmitted, String? dialogBoxTitle})
→ Future<void>
-
-
updateEvent(BuildContext context, {required String eventId, required Event event, Function? onPermissionDenied, Function? onError, Function? onSubmitted})
→ Future<void>
-